@@ -40,6 +40,7 @@ import org.eclipse.aether.util.graph.selector.AndDependencySelector;
 import org.eclipse.aether.util.graph.selector.ExclusionDependencySelector;
 import org.eclipse.aether.util.graph.selector.OptionalDependencySelector;
 import org.eclipse.aether.util.graph.transformer.*;
+import org.codehaus.plexus.util.StringUtils;
 
 import java.io.File;
 import java.lang.reflect.InvocationTargetException;
@@ -47,15 +48,12 @@ import java.lang.reflect.Method;
 import java.util.*;
 
 import static java.lang.String.*;
-import static org.apache.commons.lang.reflect.MethodUtils.invokeMethod;
+import static org.apache.commons.lang3.reflect.MethodUtils.invokeMethod;
 import static org.apache.karaf.deployer.kar.KarArtifactInstaller.FEATURE_CLASSIFIER;
 
 /**
  * <p>{@link DependencyHelper} for accessing Eclipse Aether system used in Maven 3.1+. It uses reflection to access
  * these methods of {@code maven-core} APIs which directly references Eclipse Aether classes.</p>
- *
- * <p>When {@code karaf-maven-plugin} switches to {@code maven-core:3.1.0+}, reflection should be use for Sonatype
- * Aether in {@link Dependency30Helper} and this class will use Maven API directly.</p>
  */
 public class Dependency31Helper implements DependencyHelper {
 
@@ -77,7 +75,7 @@ public class Dependency31Helper implements DependencyHelper {
     private final SimpleLRUCache<Artifact, ArtifactResult> artifactCache;
 
     // dependencies we are interested in
-    protected Set<LocalDependency> localDependencies;
+    protected Map<Artifact, LocalDependency> localDependencies;
     // log of what happened during search
     protected String treeListing;
 
@@ -102,8 +100,8 @@ public class Dependency31Helper implements DependencyHelper {
     }
 
     @Override
-    public Set<LocalDependency> getLocalDependencies() {
-        return localDependencies;
+    public Collection<LocalDependency> getLocalDependencies() {
+        return localDependencies.values();
     }
 
     @Override
@@ -190,7 +188,7 @@ public class Dependency31Helper implements DependencyHelper {
 
     private static class Scanner {
 
-        private static enum Accept {
+        private enum Accept {
             ACCEPT(true, true),
             PROVIDED(true, false),
             STOP(false, false);
@@ -198,7 +196,7 @@ public class Dependency31Helper implements DependencyHelper {
             private final boolean more;
             private final boolean local;
 
-            private Accept(boolean more, boolean local) {
+            Accept(boolean more, boolean local) {
                 this.more = more;
                 this.local = local;
             }
@@ -213,7 +211,7 @@ public class Dependency31Helper implements DependencyHelper {
         }
 
         // all the dependencies needed, with provided dependencies removed
-        private final Set<LocalDependency> localDependencies = new LinkedHashSet<>();
+        private final Map<Artifact, LocalDependency> localDependencies = new LinkedHashMap<>();
 
         // dependencies from ancestor, to be removed from localDependencies
         private final Set<Artifact> dependencies = new LinkedHashSet<>();
@@ -222,14 +220,16 @@ public class Dependency31Helper implements DependencyHelper {
 
         public void scan(DependencyNode rootNode, boolean useTransitiveDependencies) throws MojoExecutionException {
             for (DependencyNode child : rootNode.getChildren()) {
-                scan(rootNode, child, Accept.ACCEPT, useTransitiveDependencies, false, "");
+                scan(rootNode, child, Accept.ACCEPT, useTransitiveDependencies, false, 0);
             }
             if (useTransitiveDependencies) {
-                localDependencies.removeAll(dependencies);
+                localDependencies.keySet().removeAll(dependencies);
             }
         }
 
-        private void scan(DependencyNode parentNode, DependencyNode dependencyNode, Accept parentAccept, boolean useTransitiveDependencies, boolean isFromFeature, String indent) throws MojoExecutionException {
+        private void scan(DependencyNode parentNode, DependencyNode dependencyNode, Accept parentAccept, boolean useTransitiveDependencies, boolean isFromFeature, int transitiveLevel) throws MojoExecutionException {
+            String indent = StringUtils.repeat(" ", transitiveLevel);
+
             Accept accept = accept(dependencyNode, parentAccept);
             if (accept.isLocal()) {
                 if (isFromFeature) {
@@ -241,12 +241,13 @@ public class Dependency31Helper implements DependencyHelper {
                     }
                 } else {
                     log.append(indent).append("local:").append(dependencyNode).append("\n");
-                    if (localDependencies.contains(dependencyNode.getDependency().getArtifact())) {
+                    if (localDependencies.keySet().contains(dependencyNode.getDependency().getArtifact())) {
                         log.append(indent).append("already in feature, returning:").append(dependencyNode).append("\n");
                         return;
                     }
                     // TODO resolve scope conflicts
-                    localDependencies.add(new LocalDependency(dependencyNode.getDependency().getScope(), dependencyNode.getDependency().getArtifact(), parentNode.getDependency().getArtifact()));
+                    localDependencies.put(dependencyNode.getDependency().getArtifact(),
+                            new LocalDependency(dependencyNode.getDependency().getScope(), transitiveLevel > 0, dependencyNode.getDependency().getArtifact(), parentNode.getDependency().getArtifact()));
                     if (isFeature(dependencyNode) || !useTransitiveDependencies) {
                         isFromFeature = true;
                     }
@@ -254,7 +255,7 @@ public class Dependency31Helper implements DependencyHelper {
                 if (useTransitiveDependencies && accept.isContinue()) {
                     List<DependencyNode> children = dependencyNode.getChildren();
                     for (DependencyNode child : children) {
-                        scan(dependencyNode, child, accept, useTransitiveDependencies, isFromFeature, indent + " ");
+                        scan(dependencyNode, child, accept, useTransitiveDependencies, isFromFeature, transitiveLevel + 1);
                     }
                 }
             }
