@@ -427,36 +427,32 @@ public class Parser
         if ( m.matches() )
         {
             this.m_version = m.group( 1 ) + "-" + "SNAPSHOT";
-            String ret = new StringBuilder()
-                .append( m_group.replaceAll( GROUP_SEPARATOR, FILE_SEPARATOR ) )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( FILE_SEPARATOR )
-                .append( m_version )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( VERSION_SEPARATOR )
-                .append( m_version )
-                .append( m_fullClassifier )
-                .append( TYPE_SEPARATOR )
-                .append( m_type )
-                .toString();
+            String ret = m_group.replaceAll(GROUP_SEPARATOR, FILE_SEPARATOR)
+                + FILE_SEPARATOR
+                + m_artifact
+                + FILE_SEPARATOR
+                + m_version
+                + FILE_SEPARATOR
+                + m_artifact
+                + VERSION_SEPARATOR
+                + m_version
+                + m_fullClassifier
+                + TYPE_SEPARATOR
+                + m_type;
             return ret;
         } else {
-            return new StringBuilder()
-                .append( m_group.replaceAll( GROUP_SEPARATOR, FILE_SEPARATOR ) )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( FILE_SEPARATOR )
-                .append( version )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( VERSION_SEPARATOR )
-                .append( version )
-                .append( m_fullClassifier )
-                .append( TYPE_SEPARATOR )
-                .append( m_type )
-                .toString();
+            return m_group.replaceAll(GROUP_SEPARATOR, FILE_SEPARATOR)
+                + FILE_SEPARATOR
+                + m_artifact
+                + FILE_SEPARATOR
+                + version
+                + FILE_SEPARATOR
+                + m_artifact
+                + VERSION_SEPARATOR
+                + version
+                + m_fullClassifier
+                + TYPE_SEPARATOR
+                + m_type;
         }
     }
 
@@ -483,20 +479,18 @@ public class Parser
      */
     public String getSnapshotPath( final String version, final String timestamp, final String buildnumber )
     {
-        return new StringBuilder()
-                .append( m_group.replaceAll( GROUP_SEPARATOR, FILE_SEPARATOR ) )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( FILE_SEPARATOR )
-                .append( version )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( VERSION_SEPARATOR )
-                .append( getSnapshotVersion( version, timestamp, buildnumber ) )
-                .append( m_fullClassifier )
-                .append( TYPE_SEPARATOR )
-                .append( m_type )
-                .toString();
+        return m_group.replaceAll(GROUP_SEPARATOR, FILE_SEPARATOR)
+            + FILE_SEPARATOR
+            + m_artifact
+            + FILE_SEPARATOR
+            + version
+            + FILE_SEPARATOR
+            + m_artifact
+            + VERSION_SEPARATOR
+            + getSnapshotVersion(version, timestamp, buildnumber)
+            + m_fullClassifier
+            + TYPE_SEPARATOR
+            + m_type;
     }
 
     /**
@@ -507,15 +501,13 @@ public class Parser
      */
     public String getVersionMetadataPath( final String version )
     {
-        return new StringBuilder()
-                .append( m_group.replaceAll( GROUP_SEPARATOR, FILE_SEPARATOR ) )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( FILE_SEPARATOR )
-                .append( version )
-                .append( FILE_SEPARATOR )
-                .append( METADATA_FILE )
-                .toString();
+        return m_group.replaceAll(GROUP_SEPARATOR, FILE_SEPARATOR)
+            + FILE_SEPARATOR
+            + m_artifact
+            + FILE_SEPARATOR
+            + version
+            + FILE_SEPARATOR
+            + METADATA_FILE;
     }
 
     /**
@@ -526,15 +518,13 @@ public class Parser
      */
     public String getVersionLocalMetadataPath( final String version )
     {
-        return new StringBuilder()
-                .append( m_group.replaceAll( GROUP_SEPARATOR, FILE_SEPARATOR ) )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( FILE_SEPARATOR )
-                .append( version )
-                .append( FILE_SEPARATOR )
-                .append( METADATA_FILE_LOCAL )
-                .toString();
+        return m_group.replaceAll(GROUP_SEPARATOR, FILE_SEPARATOR)
+            + FILE_SEPARATOR
+            + m_artifact
+            + FILE_SEPARATOR
+            + version
+            + FILE_SEPARATOR
+            + METADATA_FILE_LOCAL;
     }
 
     /**
@@ -544,13 +534,11 @@ public class Parser
      */
     public String getArtifactLocalMetdataPath()
     {
-        return new StringBuilder()
-                .append( m_group.replaceAll( GROUP_SEPARATOR, FILE_SEPARATOR ) )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( FILE_SEPARATOR )
-                .append( METADATA_FILE_LOCAL )
-                .toString();
+        return m_group.replaceAll(GROUP_SEPARATOR, FILE_SEPARATOR)
+            + FILE_SEPARATOR
+            + m_artifact
+            + FILE_SEPARATOR
+            + METADATA_FILE_LOCAL;
     }
 
     /**
@@ -560,13 +548,11 @@ public class Parser
      */
     public String getArtifactMetdataPath()
     {
-        return new StringBuilder()
-                .append( m_group.replaceAll( GROUP_SEPARATOR, FILE_SEPARATOR ) )
-                .append( FILE_SEPARATOR )
-                .append( m_artifact )
-                .append( FILE_SEPARATOR )
-                .append( METADATA_FILE )
-                .toString();
+        return m_group.replaceAll(GROUP_SEPARATOR, FILE_SEPARATOR)
+            + FILE_SEPARATOR
+            + m_artifact
+            + FILE_SEPARATOR
+            + METADATA_FILE;
     }
 
 }
